summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/buttongroup.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/buttongroup.h')
-rw-r--r--kalarm/lib/buttongroup.h29
1 files changed, 15 insertions, 14 deletions
diff --git a/kalarm/lib/buttongroup.h b/kalarm/lib/buttongroup.h
index 8fbadae77..9d4a8886a 100644
--- a/kalarm/lib/buttongroup.h
+++ b/kalarm/lib/buttongroup.h
@@ -1,5 +1,5 @@
/*
- * buttongroup.h - TQButtonGroup with an extra signal and Qt 2 compatibility
+ * buttongroup.h - TQButtonGroup with an extra signal and TQt 2 compatibility
* Program: kalarm
* Copyright © 2002,2004,2006 by David Jarvie <software@astrojar.org.uk>
*
@@ -24,47 +24,48 @@
/**
- * @short A TQButtonGroup with signal on new selection, plus Qt 2 compatibility.
+ * @short A TQButtonGroup with signal on new selection, plus TQt 2 compatibility.
*
* The ButtonGroup class provides an enhanced version of the TQButtonGroup class.
*
* It emits an additional signal, buttonSet(int), whenever any of its buttons
* changes state, for whatever reason, including programmatic control. (The
* TQButtonGroup class only emits signals when buttons are clicked on by the user.)
- * The class also provides Qt 2 compatibility.
+ * The class also provides TQt 2 compatibility.
*
* @author David Jarvie <software@astrojar.org.uk>
*/
-class ButtonGroup : public QButtonGroup
+class ButtonGroup : public TQButtonGroup
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructor.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit ButtonGroup(TQWidget* parent, const char* name = 0);
+ explicit ButtonGroup(TQWidget* tqparent, const char* name = 0);
/** Constructor.
* @param title The title displayed for this button group.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- ButtonGroup(const TQString& title, TQWidget* parent, const char* name = 0);
+ ButtonGroup(const TQString& title, TQWidget* tqparent, const char* name = 0);
/** Constructor.
* @param strips The number of rows or columns of buttons.
* @param orient The orientation (Qt::Horizontal or Qt::Vertical) of the button group.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- ButtonGroup(int strips, Qt::Orientation orient, TQWidget* parent, const char* name = 0);
+ ButtonGroup(int strips, Qt::Orientation orient, TQWidget* tqparent, const char* name = 0);
/** Constructor.
* @param strips The number of rows or columns of buttons.
- * @param orient The orientation (Qt::Horizontal or Qt::Vertical) of the button group.
+ * @param orient The orientation (TQt::Horizontal or TQt::Vertical) of the button group.
* @param title The title displayed for this button group.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- ButtonGroup(int strips, Qt::Orientation orient, const TQString& title, TQWidget* parent, const char* name = 0);
+ ButtonGroup(int strips, Qt::Orientation orient, const TQString& title, TQWidget* tqparent, const char* name = 0);
/** Inserts a button in the group.
* This overrides the insert() method of TQButtonGroup, which should really be a virtual method...
* @param button The button to insert.
@@ -24,47 +24,48 @@
public:
/** Constructor.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -24,47 +24,48 @@
/** Constructor.
* @param title The title displayed for this button group.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -24,47 +24,48 @@
/** Constructor.
* @param strips The number of rows or columns of buttons.
- * @param orient The orientation (Qt::Horizontal or Qt::Vertical) of the button group.
- * @param parent The parent object of this widget.
+ * @param orient The orientation (TQt::Horizontal or TQt::Vertical) of the button group.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -24,47 +24,48 @@
* @param title The title displayed for this button group.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/